@@ -1,7 +1,11 @@
 # -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MIT
+from __future__ import absolute_import
 import calendar
+import distro
 import hashlib
+from io import open
+from itertools import chain
 import logging
 import json
 import os
@@ -11,28 +15,22 @@ import shutil
 import subprocess
 import tempfile
 import time
-from io import open
-from itertools import chain
 
 import kobo.rpmlib
-
-from six import text_type
 import koji
 import pungi.arch
+from six import text_type
 
-from module_build_service import conf, log, build_logs, models, Modulemd
-from module_build_service.scm import SCM
-from module_build_service.utils import to_text_type, load_mmd, mmd_to_str
+from module_build_service.common.modulemd import Modulemd
+from module_build_service.common import conf, log, build_logs
+from module_build_service.common.koji import get_session, koji_retrying_multicall_map
+from module_build_service.common.scm import SCM
+from module_build_service.common.utils import load_mmd, mmd_to_str, to_text_type
+from module_build_service.scheduler.db_session import db_session
 
 logging.basicConfig(level=logging.DEBUG)
 
 
-def get_session(config, login=True):
-    from module_build_service.builder.KojiModuleBuilder import KojiModuleBuilder
-
-    return KojiModuleBuilder.get_session(config, login=login)
-
-
 def strip_suffixes(s, suffixes):
     """
     Helper function to remove suffixes from given string.
@@ -52,24 +50,13 @@ def strip_suffixes(s, suffixes):
     return s
 
 
-def koji_retrying_multicall_map(*args, **kwargs):
-    """
-    Wrapper around KojiModuleBuilder.koji_retrying_multicall_map, because
-    we cannot import that method normally because of import loop.
-    """
-    from module_build_service.builder.KojiModuleBuilder import (
-        koji_retrying_multicall_map as multicall,)
-
-    return multicall(*args, **kwargs)
-
-
 class KojiContentGenerator(object):
     """ Class for handling content generator imports of module builds into Koji """
 
     def __init__(self, module, config):
         """
-        :param module: module_build_service.models.ModuleBuild instance.
-        :param config: module_build_service.config.Config instance
+        :param module: module_build_service.common.models.ModuleBuild instance.
+        :param config: module_build_service.common.config.Config instance
         """
         self.owner = module.owner
         self.module = module
@@ -276,7 +263,7 @@ class KojiContentGenerator(object):
                 u"module": {
                     u"module_build_service_id": self.module.id,
                     u"content_koji_tag": self.module.koji_tag,
-                    u"modulemd_str": self.module.modulemd,
+                    u"modulemd_str": self._get_fixed_mmd(),
                     u"name": ret["name"],
                     u"stream": self.module.stream,
                     u"version": self.module.version,
@@ -292,12 +279,12 @@ class KojiContentGenerator(object):
 
     def _get_buildroot(self):
         version = pkg_resources.get_distribution("module-build-service").version
-        distro = platform.linux_distribution()
+        distro_info = distro.linux_distribution()
         ret = {
             u"id": 1,
             u"host": {
                 u"arch": text_type(platform.machine()),
-                u"os": u"%s %s" % (distro[0], distro[1]),
+                u"os": u"%s %s" % (distro_info[0], distro_info[1]),
             },
             u"content_generator": {
                 u"name": u"module-build-service",
@@ -327,6 +314,16 @@ class KojiContentGenerator(object):
             u"type": u"rpm",
         }
 
+    def _get_fixed_mmd(self):
+        if self.devel:
+            mmd = self.module.mmd()
+            mmd = mmd.copy(mmd.get_module_name() + "-devel")
+            ret = mmd_to_str(mmd)
+        else:
+            ret = self.mmd
+
+        return ret
+
     def _get_arch_mmd_output(self, output_path, arch):
         """
         Returns the CG "output" dict for architecture specific modulemd file.
@@ -753,7 +750,7 @@ class KojiContentGenerator(object):
         mmd_path = os.path.join(prepdir, "modulemd.txt")
         log.info("Writing generic modulemd.yaml to %r" % mmd_path)
         with open(mmd_path, "w", encoding="utf-8") as mmd_f:
-            mmd_f.write(self.mmd)
+            mmd_f.write(self._get_fixed_mmd())
 
         mmd_path = os.path.join(prepdir, "modulemd.src.txt")
         self._download_source_modulemd(self.module.mmd(), mmd_path)
@@ -767,8 +764,7 @@ class KojiContentGenerator(object):
 
         log_path = os.path.join(prepdir, "build.log")
         try:
-            with models.make_db_session(conf) as db_session:
-                source = build_logs.path(db_session, self.module)
+            source = build_logs.path(db_session, self.module)
             log.info("Moving logs from %r to %r" % (source, log_path))
             shutil.copy(source, log_path)
         except IOError as e:
