@@ -1,30 +1,36 @@
 # -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MIT
-import functools
-import os
+from __future__ import absolute_import
 from datetime import datetime, timedelta
-from mock import patch
-from six import string_types
-import time
+import functools
 import hashlib
+import itertools
+import os
+import re
+import six
+import time
 from traceback import extract_stack
-from module_build_service.utils import to_text_type, load_mmd
 
 import koji
+from mock import patch
+from six import string_types
+
 import module_build_service
 from module_build_service import db
-from module_build_service.utils import get_rpm_release, import_mmd, mmd_to_str
-from module_build_service.config import init_config
-from module_build_service.models import (
-    ModuleBuild, ModuleArch, ComponentBuild, VirtualStream,
-    make_db_session, BUILD_STATES,
+from module_build_service.builder.utils import get_rpm_release
+from module_build_service.common.models import (
+    BUILD_STATES,
+    ComponentBuild,
+    ModuleArch,
+    ModuleBuild,
+    VirtualStream,
 )
-from module_build_service import Modulemd
+from module_build_service.common.modulemd import Modulemd
+from module_build_service.common.utils import load_mmd, import_mmd, mmd_to_str, to_text_type
+from module_build_service.scheduler.db_session import db_session
 
 
 base_dir = os.path.dirname(__file__)
-app = module_build_service.app
-conf = init_config(app)
 
 
 def staged_data_filename(filename):
@@ -52,10 +58,10 @@ def read_staged_data(yaml_name):
 def patch_config():
     # add test builders for all resolvers
     with_test_builders = dict()
-    for k, v in module_build_service.config.SUPPORTED_RESOLVERS.items():
+    for k, v in module_build_service.common.config.SUPPORTED_RESOLVERS.items():
         v["builders"].extend(["test", "testlocal"])
         with_test_builders[k] = v
-    patch("module_build_service.config.SUPPORTED_RESOLVERS", with_test_builders)
+    patch("module_build_service.common.config.SUPPORTED_RESOLVERS", with_test_builders)
 
 
 patch_config()
@@ -101,15 +107,20 @@ def clean_database(add_platform_module=True, add_default_arches=True):
     Please note that, this function relies on database objects managed by
     Flask-SQLAlchemy.
     """
-    # Ensure all pending transactions are committed and do not block subsequent
-    # DML on tables.
-    # TODO: Should the code be fixed that forget to commit?
-    db.session.commit()
+
+    # Helpful for writing tests if any changes were made using the database
+    # session but the test didn't commit or rollback.
+    #
+    # clean_database is usually called before a test run. So, it makes no sense
+    # to keep any changes in the transaction made by previous test.
+    db_session.remove()
+    db_session.configure(bind=db.session.get_bind())
+
     db.drop_all()
     db.create_all()
 
     if add_default_arches:
-        arch_obj = module_build_service.models.ModuleArch(name="x86_64")
+        arch_obj = module_build_service.common.models.ModuleArch(name="x86_64")
         db.session.add(arch_obj)
         db.session.commit()
 
@@ -130,6 +141,7 @@ def init_data(data_size=10, contexts=False, multiple_stream_versions=None, scrat
         the generated base module streams.
     """
     clean_database()
+
     if multiple_stream_versions:
         if multiple_stream_versions is True:
             multiple_stream_versions = ["f28.0.0", "f29.0.0", "f29.1.0", "f29.2.0"]
@@ -147,16 +159,17 @@ def init_data(data_size=10, contexts=False, multiple_stream_versions=None, scrat
             # Just to possibly confuse tests by adding another base module.
             mmd = mmd.copy("bootstrap", stream)
             import_mmd(db.session, mmd)
-    with make_db_session(conf) as db_session:
-        _populate_data(db_session, data_size, contexts=contexts, scratch=scratch)
+
+    _populate_data(data_size, contexts=contexts, scratch=scratch)
 
 
-def _populate_data(db_session, data_size=10, contexts=False, scratch=False):
+def _populate_data(data_size=10, contexts=False, scratch=False):
     # Query arch from passed database session, otherwise there will be an error
     # like "Object '<ModuleBuild at 0x7f4ccc805c50>' is already attached to
     # session '275' (this is '276')" when add new module build object to passed
     # session.
-    arch = db_session.query(module_build_service.models.ModuleArch).get(1)
+    task_id_counter = itertools.count(1)
+    arch = db_session.query(module_build_service.common.models.ModuleArch).get(1)
     num_contexts = 2 if contexts else 1
     for index in range(data_size):
         for context in range(num_contexts):
@@ -205,7 +218,7 @@ def _populate_data(db_session, data_size=10, contexts=False, scratch=False):
                     scmurl="git://pkgs.domain.local/rpms/nginx?"
                            "#ga95886c8a443b36a9ce31abda1f9bed22f2f8c3",
                     format="rpms",
-                    task_id=12312345 + index,
+                    task_id=six.next(task_id_counter),
                     state=koji.BUILD_STATES["COMPLETE"],
                     nvr="nginx-1.10.1-2.{0}".format(build_one_component_release),
                     batch=1,
@@ -217,7 +230,7 @@ def _populate_data(db_session, data_size=10, contexts=False, scratch=False):
                     scmurl="/tmp/module_build_service-build-macrosWZUPeK/SRPMS/"
                            "module-build-macros-0.1-1.module_nginx_1_2.src.rpm",
                     format="rpms",
-                    task_id=12312321 + index,
+                    task_id=six.next(task_id_counter),
                     state=koji.BUILD_STATES["COMPLETE"],
                     nvr="module-build-macros-01-1.{0}".format(build_one_component_release),
                     batch=2,
@@ -326,7 +339,7 @@ def _populate_data(db_session, data_size=10, contexts=False, scratch=False):
         db_session.commit()
 
 
-def scheduler_init_data(db_session, tangerine_state=None, scratch=False):
+def scheduler_init_data(tangerine_state=None, scratch=False):
     """ Creates a testmodule in the building state with all the components in the same batch
     """
     clean_database()
@@ -334,7 +347,7 @@ def scheduler_init_data(db_session, tangerine_state=None, scratch=False):
     mmd = load_mmd(read_staged_data("formatted_testmodule"))
     mmd.get_rpm_component("tangerine").set_buildorder(0)
 
-    module_build = module_build_service.models.ModuleBuild(
+    module_build = module_build_service.common.models.ModuleBuild(
         name="testmodule",
         stream="master",
         version='20170109091357',
@@ -359,16 +372,16 @@ def scheduler_init_data(db_session, tangerine_state=None, scratch=False):
     db_session.add(module_build)
     db_session.commit()
 
-    platform_br = module_build_service.models.ModuleBuild.get_by_id(db_session, 1)
+    platform_br = module_build_service.common.models.ModuleBuild.get_by_id(db_session, 1)
     module_build.buildrequires.append(platform_br)
 
-    arch = db_session.query(module_build_service.models.ModuleArch).get(1)
+    arch = db_session.query(module_build_service.common.models.ModuleArch).get(1)
     module_build.arches.append(arch)
 
     build_one_component_release = get_rpm_release(db_session, module_build)
 
     db_session.add_all([
-        module_build_service.models.ComponentBuild(
+        module_build_service.common.models.ComponentBuild(
             module_id=module_build.id,
             package="perl-Tangerine",
             scmurl="https://src.fedoraproject.org/rpms/perl-Tangerine"
@@ -382,7 +395,7 @@ def scheduler_init_data(db_session, tangerine_state=None, scratch=False):
             tagged=True,
             tagged_in_final=True,
         ),
-        module_build_service.models.ComponentBuild(
+        module_build_service.common.models.ComponentBuild(
             module_id=module_build.id,
             package="perl-List-Compare",
             scmurl="https://src.fedoraproject.org/rpms/perl-List-Compare"
@@ -396,7 +409,7 @@ def scheduler_init_data(db_session, tangerine_state=None, scratch=False):
             tagged=True,
             tagged_in_final=True,
         ),
-        module_build_service.models.ComponentBuild(
+        module_build_service.common.models.ComponentBuild(
             module_id=module_build.id,
             package="tangerine",
             scmurl="https://src.fedoraproject.org/rpms/tangerine"
@@ -412,7 +425,7 @@ def scheduler_init_data(db_session, tangerine_state=None, scratch=False):
             tagged=tangerine_state == koji.BUILD_STATES["COMPLETE"],
             tagged_in_final=tangerine_state == koji.BUILD_STATES["COMPLETE"],
         ),
-        module_build_service.models.ComponentBuild(
+        module_build_service.common.models.ComponentBuild(
             module_id=module_build.id,
             package="module-build-macros",
             scmurl="/tmp/module_build_service-build-macrosqr4AWH/SRPMS/module-build-"
@@ -435,7 +448,6 @@ def make_module(
     base_module=None,
     filtered_rpms=None,
     xmd=None,
-    db_session=None,
     store_to_db=False,
     virtual_streams=None,
     arches=None,
@@ -459,7 +471,6 @@ def make_module(
     :param dict xmd: a mapping representing XMD section in module metadata. A
         custom xmd could be passed for testing a particular scenario and some
         default key/value pairs are added if not present.
-    :param db_session: SQLAlchemy database session.
     :param bool store_to_db: whether to store created module metadata to the
         database. If set to True, ``db_session`` is required.
     :param virtual_streams: List of virtual streams provided by this module.
@@ -479,14 +490,22 @@ def make_module(
     if base_module:
         assert db_session is not None
     if virtual_streams:
-        assert db_session and store_to_db
+        assert store_to_db
     if arches:
-        assert db_session and store_to_db
+        assert store_to_db
+
+    nsvc_regex = re.compile(r"([^:]+):([^:]+):([^:]+)(?::(.+))?")
+
+    match = nsvc_regex.match(nsvc)
+    if not match:
+        raise ValueError('Argument nsvc is not in format N:S:V or N:S:V:C')
+
+    name, stream, version, context = match.groups()
 
-    name, stream, version, context = nsvc.split(":")
     mmd = Modulemd.ModuleStreamV2.new(name, stream)
     mmd.set_version(int(version))
-    mmd.set_context(context)
+    if context:
+        mmd.set_context(context)
     mmd.set_summary("foo")
     # Test unicode in mmd.
     mmd.set_description(u"foo \u2019s")
