@@ -1,23 +1,28 @@
 # -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MIT
+from __future__ import absolute_import
 import os
 
 from datetime import datetime
 from mock import patch, PropertyMock
 import pytest
 
+from module_build_service.builder.MockModuleBuilder import load_local_builds
+from module_build_service.common import models
+from module_build_service.common.config import conf
+from module_build_service.common.errors import UnprocessableEntity
+from module_build_service.common.models import ModuleBuild
+from module_build_service.common.modulemd import Modulemd
+from module_build_service.common.utils import import_mmd, load_mmd, mmd_to_str
 import module_build_service.resolver as mbs_resolver
-from module_build_service import models, utils, Modulemd
-from module_build_service.utils import import_mmd, mmd_to_str, load_mmd
-from module_build_service.models import ModuleBuild
-from module_build_service.errors import UnprocessableEntity
+from module_build_service.scheduler.db_session import db_session
 import tests
 
 
 @pytest.mark.usefixtures("reuse_component_init_data")
 class TestDBModule:
 
-    def test_get_buildrequired_modulemds(self, db_session):
+    def test_get_buildrequired_modulemds(self):
         mmd = load_mmd(tests.read_staged_data("platform"))
         mmd = mmd.copy(mmd.get_module_name(), "f30.1.3")
 
@@ -45,20 +50,20 @@ class TestDBModule:
         db_session.add(build)
         db_session.commit()
 
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         result = resolver.get_buildrequired_modulemds(
             "testmodule", "master", platform_f300103.mmd())
         nsvcs = {m.get_nsvc() for m in result}
         assert nsvcs == {"testmodule:master:20170109091357:123"}
 
     @pytest.mark.parametrize("stream_versions", [False, True])
-    def test_get_compatible_base_module_modulemds_stream_versions(
-        self, stream_versions, db_session
-    ):
+    def test_get_compatible_base_module_modulemds_stream_versions(self, stream_versions):
         tests.init_data(1, multiple_stream_versions=True)
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
+        platform = db_session.query(ModuleBuild).filter_by(name="platform", stream="f29.1.0").one()
+        platform_mmd = platform.mmd()
         result = resolver.get_compatible_base_module_modulemds(
-            "platform", "f29.1.0", stream_version_lte=stream_versions, virtual_streams=["f29"],
+            platform_mmd, stream_version_lte=stream_versions, virtual_streams=["f29"],
             states=[models.BUILD_STATES["ready"]])
         nsvcs = {mmd.get_nsvc() for mmd in result}
         if stream_versions:
@@ -71,7 +76,7 @@ class TestDBModule:
             }
 
     @pytest.mark.parametrize("empty_buildrequires", [False, True])
-    def test_get_module_build_dependencies(self, empty_buildrequires, db_session):
+    def test_get_module_build_dependencies(self, empty_buildrequires):
         """
         Tests that the buildrequires of testmodule are returned
         """
@@ -88,12 +93,12 @@ class TestDBModule:
             mmd.set_xmd(xmd)
             module.modulemd = mmd_to_str(mmd)
             db_session.commit()
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         result = resolver.get_module_build_dependencies(
             "testmodule", "master", "20170109091357", "78e4a6fd").keys()
         assert set(result) == expected
 
-    def test_get_module_build_dependencies_recursive(self, db_session):
+    def test_get_module_build_dependencies_recursive(self):
         """
         Tests that the buildrequires are returned when it is two layers deep
         """
@@ -121,29 +126,29 @@ class TestDBModule:
 
         db_session.commit()
 
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         result = resolver.get_module_build_dependencies(
             "testmodule2", "master", "20180123171545", "c40c156c").keys()
         assert set(result) == {"module-f28-build"}
 
     @patch(
-        "module_build_service.config.Config.system", new_callable=PropertyMock, return_value="test"
+        "module_build_service.common.config.Config.system",
+        new_callable=PropertyMock,
+        return_value="test",
     )
     @patch(
-        "module_build_service.config.Config.mock_resultsdir",
+        "module_build_service.common.config.Config.mock_resultsdir",
         new_callable=PropertyMock,
         return_value=tests.staged_data_filename("local_builds"),
     )
-    def test_get_module_build_dependencies_recursive_requires(
-        self, resultdir, conf_system, db_session
-    ):
+    def test_get_module_build_dependencies_recursive_requires(self, resultdir, conf_system):
         """
         Tests that it returns the requires of the buildrequires recursively
         """
-        utils.load_local_builds(db_session, ["platform", "parent", "child", "testmodule"])
+        load_local_builds(["platform:f30", "parent", "child", "testmodule"])
 
         build = models.ModuleBuild.local_modules(db_session, "child", "master")
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         result = resolver.get_module_build_dependencies(mmd=build[0].mmd()).keys()
 
         local_path = tests.staged_data_filename("local_builds")
@@ -151,9 +156,9 @@ class TestDBModule:
         expected = [os.path.join(local_path, "module-parent-master-20170816080815/results")]
         assert set(result) == set(expected)
 
-    def test_resolve_requires(self, db_session):
+    def test_resolve_requires(self):
         build = models.ModuleBuild.get_by_id(db_session, 2)
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         result = resolver.resolve_requires(
             [":".join([build.name, build.stream, build.version, build.context])]
         )
@@ -168,20 +173,21 @@ class TestDBModule:
             }
         }
 
-    def test_resolve_requires_exception(self, db_session):
+    def test_resolve_requires_exception(self):
         build = models.ModuleBuild.get_by_id(db_session, 2)
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         with pytest.raises(UnprocessableEntity):
             resolver.resolve_requires(
                 [":".join(["abcdefghi", build.stream, build.version, build.context])]
             )
 
-    def test_resolve_requires_siblings(self, db_session):
+    def test_resolve_requires_siblings(self):
         tests.clean_database()
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         mmd = load_mmd(tests.read_staged_data("formatted_testmodule"))
         for i in range(3):
             build = tests.module_build_from_modulemd(mmd_to_str(mmd))
+            build.context = "f6e2ae" + str(i)
             build.build_context = "f6e2aeec7576196241b9afa0b6b22acf2b6873d" + str(i)
             build.runtime_context = "bbc84c7b817ab3dd54916c0bcd6c6bdf512f7f9c" + str(i)
             build.state = models.BUILD_STATES["ready"]
@@ -203,12 +209,12 @@ class TestDBModule:
 
         db_session.commit()
 
-    def test_resolve_profiles(self, db_session):
+    def test_resolve_profiles(self):
         """
         Tests that the profiles get resolved recursively
         """
         mmd = models.ModuleBuild.get_by_id(db_session, 2).mmd()
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         result = resolver.resolve_profiles(mmd, ("buildroot", "srpm-buildroot"))
         expected = {
             "buildroot": {
@@ -250,37 +256,47 @@ class TestDBModule:
         assert result == expected
 
     @patch(
-        "module_build_service.config.Config.system", new_callable=PropertyMock, return_value="test"
+        "module_build_service.common.config.Config.system",
+        new_callable=PropertyMock,
+        return_value="test",
     )
     @patch(
-        "module_build_service.config.Config.mock_resultsdir",
+        "module_build_service.common.config.Config.mock_resultsdir",
         new_callable=PropertyMock,
         return_value=tests.staged_data_filename("local_builds")
     )
-    def test_resolve_profiles_local_module(self, local_builds, conf_system, db_session):
+    def test_resolve_profiles_local_module(self, local_builds, conf_system):
         """
         Test that profiles get resolved recursively on local builds
         """
-        utils.load_local_builds(db_session, ["platform"])
+        # This test requires a platform module loaded from local rather than
+        # the one added to database.
+        platform = db_session.query(models.ModuleBuild).filter(
+            models.ModuleBuild.name == "platform"
+        ).one()
+        db_session.delete(platform)
+        db_session.commit()
+
+        load_local_builds(["platform:f28"])
         mmd = models.ModuleBuild.get_by_id(db_session, 2).mmd()
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
         result = resolver.resolve_profiles(mmd, ("buildroot", "srpm-buildroot"))
         expected = {"buildroot": {"foo"}, "srpm-buildroot": {"bar"}}
         assert result == expected
 
-    def test_get_latest_with_virtual_stream(self, db_session):
+    def test_get_latest_with_virtual_stream(self):
         tests.init_data(1, multiple_stream_versions=True)
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         mmd = resolver.get_latest_with_virtual_stream("platform", "f29")
         assert mmd
         assert mmd.get_stream_name() == "f29.2.0"
 
-    def test_get_latest_with_virtual_stream_none(self, db_session):
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+    def test_get_latest_with_virtual_stream_none(self):
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         mmd = resolver.get_latest_with_virtual_stream("platform", "doesnotexist")
         assert not mmd
 
-    def test_get_module_count(self, db_session):
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="db")
+    def test_get_module_count(self):
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
         count = resolver.get_module_count(name="platform", stream="f28")
         assert count == 1
