@@ -1,17 +1,22 @@
 # -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MIT
+from __future__ import absolute_import
+
 from mock import patch, PropertyMock, Mock, call
 
+from module_build_service import app
+from module_build_service.builder.MockModuleBuilder import load_local_builds
+import module_build_service.common.models
+from module_build_service.common import conf
+from module_build_service.common.utils import load_mmd, mmd_to_str
 import module_build_service.resolver as mbs_resolver
-import module_build_service.utils
-from module_build_service.utils.general import mmd_to_str
-import module_build_service.models
+from module_build_service.scheduler.db_session import db_session
 import tests
 
 
 class TestMBSModule:
     @patch("module_build_service.resolver.MBSResolver.requests_session")
-    def test_get_module_modulemds_nsvc(self, mock_session, testmodule_mmd_9c690d0e, db_session):
+    def test_get_module_modulemds_nsvc(self, mock_session, testmodule_mmd_9c690d0e):
         """ Tests for querying a module from mbs """
         mock_res = Mock()
         mock_res.ok.return_value = True
@@ -30,13 +35,13 @@ class TestMBSModule:
 
         mock_session.get.return_value = mock_res
 
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
         module_mmds = resolver.get_module_modulemds(
             "testmodule", "master", "20180205135154", "9c690d0e", virtual_streams=["f28"]
         )
         nsvcs = set(m.get_nsvc() for m in module_mmds)
         expected = {"testmodule:master:20180205135154:9c690d0e"}
-        mbs_url = tests.conf.mbs_url
+        mbs_url = conf.mbs_url
         expected_query = {
             "name": "testmodule",
             "stream": "master",
@@ -54,7 +59,7 @@ class TestMBSModule:
 
     @patch("module_build_service.resolver.MBSResolver.requests_session")
     def test_get_module_modulemds_partial(
-        self, mock_session, testmodule_mmd_9c690d0e, testmodule_mmd_c2c572ed, db_session
+        self, mock_session, testmodule_mmd_9c690d0e, testmodule_mmd_c2c572ed
     ):
         """ Test for querying MBS without the context of a module """
 
@@ -83,14 +88,14 @@ class TestMBSModule:
         }
 
         mock_session.get.return_value = mock_res
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
         ret = resolver.get_module_modulemds("testmodule", "master", version)
         nsvcs = set(m.get_nsvc() for m in ret)
         expected = {
             "testmodule:master:20180205135154:9c690d0e",
             "testmodule:master:20180205135154:c2c572ed",
         }
-        mbs_url = tests.conf.mbs_url
+        mbs_url = conf.mbs_url
         expected_query = {
             "name": "testmodule",
             "stream": "master",
@@ -106,7 +111,7 @@ class TestMBSModule:
 
     @patch("module_build_service.resolver.MBSResolver.requests_session")
     def test_get_module_build_dependencies(
-        self, mock_session, platform_mmd, testmodule_mmd_9c690d0e, db_session
+        self, mock_session, platform_mmd, testmodule_mmd_9c690d0e
     ):
         """
         Tests that we return just direct build-time dependencies of testmodule.
@@ -143,7 +148,7 @@ class TestMBSModule:
 
         mock_session.get.return_value = mock_res
         expected = {"module-f28-build"}
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
         result = resolver.get_module_build_dependencies(
             "testmodule", "master", "20180205135154", "9c690d0e").keys()
 
@@ -172,7 +177,7 @@ class TestMBSModule:
             },
         ]
 
-        mbs_url = tests.conf.mbs_url
+        mbs_url = conf.mbs_url
         expected_calls = [
             call(mbs_url, params=expected_queries[0]),
             call(mbs_url, params=expected_queries[1]),
@@ -183,10 +188,10 @@ class TestMBSModule:
 
     @patch("module_build_service.resolver.MBSResolver.requests_session")
     def test_get_module_build_dependencies_empty_buildrequires(
-        self, mock_session, testmodule_mmd_9c690d0e, db_session
+        self, mock_session, testmodule_mmd_9c690d0e
     ):
 
-        mmd = module_build_service.utils.load_mmd(testmodule_mmd_9c690d0e)
+        mmd = load_mmd(testmodule_mmd_9c690d0e)
         # Wipe out the dependencies
         for deps in mmd.get_dependencies():
             mmd.remove_dependencies(deps)
@@ -216,11 +221,11 @@ class TestMBSModule:
 
         expected = set()
 
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
         result = resolver.get_module_build_dependencies(
             "testmodule", "master", "20180205135154", "9c690d0e"
         ).keys()
-        mbs_url = tests.conf.mbs_url
+        mbs_url = conf.mbs_url
         expected_query = {
             "name": "testmodule",
             "stream": "master",
@@ -237,7 +242,7 @@ class TestMBSModule:
 
     @patch("module_build_service.resolver.MBSResolver.requests_session")
     def test_resolve_profiles(
-        self, mock_session, formatted_testmodule_mmd, platform_mmd, db_session
+        self, mock_session, formatted_testmodule_mmd, platform_mmd
     ):
 
         mock_res = Mock()
@@ -256,7 +261,7 @@ class TestMBSModule:
         }
 
         mock_session.get.return_value = mock_res
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
         result = resolver.resolve_profiles(
             formatted_testmodule_mmd, ("buildroot", "srpm-buildroot")
         )
@@ -298,7 +303,7 @@ class TestMBSModule:
             },
         }
 
-        mbs_url = tests.conf.mbs_url
+        mbs_url = conf.mbs_url
         expected_query = {
             "name": "platform",
             "stream": "f28",
@@ -315,38 +320,41 @@ class TestMBSModule:
         assert result == expected
 
     @patch(
-        "module_build_service.config.Config.system", new_callable=PropertyMock, return_value="test"
+        "module_build_service.common.config.Config.system",
+        new_callable=PropertyMock,
+        return_value="test",
     )
     @patch(
-        "module_build_service.config.Config.mock_resultsdir",
+        "module_build_service.common.config.Config.mock_resultsdir",
         new_callable=PropertyMock,
         return_value=tests.staged_data_filename("local_builds")
     )
     def test_resolve_profiles_local_module(
-        self, local_builds, conf_system, formatted_testmodule_mmd, db_session
+        self, local_builds, conf_system, formatted_testmodule_mmd
     ):
-        tests.clean_database()
-        with tests.app.app_context():
-            module_build_service.utils.load_local_builds(db_session, ["platform"])
+        tests.clean_database(add_platform_module=False)
+        load_local_builds(["platform:f28"])
 
-            resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
-            result = resolver.resolve_profiles(
-                formatted_testmodule_mmd, ("buildroot", "srpm-buildroot"))
-            expected = {"buildroot": {"foo"}, "srpm-buildroot": {"bar"}}
-            assert result == expected
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
+        result = resolver.resolve_profiles(
+            formatted_testmodule_mmd, ("buildroot", "srpm-buildroot"))
+        expected = {"buildroot": {"foo"}, "srpm-buildroot": {"bar"}}
+        assert result == expected
 
     @patch("module_build_service.resolver.MBSResolver.requests_session")
-    def test_get_empty_buildrequired_modulemds(self, request_session, db_session):
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+    def test_get_empty_buildrequired_modulemds(self, request_session):
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
         request_session.get.return_value = Mock(ok=True)
         request_session.get.return_value.json.return_value = {"items": [], "meta": {"next": None}}
 
-        result = resolver.get_buildrequired_modulemds("nodejs", "10", "platform:el8:1:00000000")
+        platform = db_session.query(
+            module_build_service.common.models.ModuleBuild).filter_by(id=1).one()
+        result = resolver.get_buildrequired_modulemds("nodejs", "10", platform.mmd())
         assert [] == result
 
     @patch("module_build_service.resolver.MBSResolver.requests_session")
-    def test_get_buildrequired_modulemds(self, mock_session, db_session):
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+    def test_get_buildrequired_modulemds(self, mock_session):
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
         mock_session.get.return_value = Mock(ok=True)
         mock_session.get.return_value.json.return_value = {
             "items": [
@@ -372,7 +380,9 @@ class TestMBSModule:
             "meta": {"next": None},
         }
 
-        result = resolver.get_buildrequired_modulemds("nodejs", "10", "platform:el8:1:00000000")
+        platform = db_session.query(
+            module_build_service.common.models.ModuleBuild).filter_by(id=1).one()
+        result = resolver.get_buildrequired_modulemds("nodejs", "10", platform.mmd())
 
         assert 1 == len(result)
         mmd = result[0]
@@ -382,7 +392,7 @@ class TestMBSModule:
         assert "c1" == mmd.get_context()
 
     @patch("module_build_service.resolver.MBSResolver.requests_session")
-    def test_get_module_count(self, mock_session, db_session):
+    def test_get_module_count(self, mock_session):
         mock_res = Mock()
         mock_res.ok.return_value = True
         mock_res.json.return_value = {
@@ -391,7 +401,7 @@ class TestMBSModule:
         }
         mock_session.get.return_value = mock_res
 
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
         count = resolver.get_module_count(name="platform", stream="f28")
 
         assert count == 5
@@ -401,7 +411,7 @@ class TestMBSModule:
         )
 
     @patch("module_build_service.resolver.MBSResolver.requests_session")
-    def test_get_latest_with_virtual_stream(self, mock_session, platform_mmd, db_session):
+    def test_get_latest_with_virtual_stream(self, mock_session, platform_mmd):
         mock_res = Mock()
         mock_res.ok.return_value = True
         mock_res.json.return_value = {
@@ -418,7 +428,7 @@ class TestMBSModule:
         }
         mock_session.get.return_value = mock_res
 
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
         mmd = resolver.get_latest_with_virtual_stream("platform", "virtualf28")
 
         assert mmd.get_module_name() == "platform"
@@ -435,21 +445,23 @@ class TestMBSModule:
         )
 
     @patch(
-        "module_build_service.config.Config.system", new_callable=PropertyMock, return_value="test"
+        "module_build_service.common.config.Config.system",
+        new_callable=PropertyMock,
+        return_value="test",
     )
     @patch(
-        "module_build_service.config.Config.mock_resultsdir",
+        "module_build_service.common.config.Config.mock_resultsdir",
         new_callable=PropertyMock,
         return_value=tests.staged_data_filename("local_builds")
     )
     def test_get_buildrequired_modulemds_local_builds(
-        self, local_builds, conf_system, db_session
+        self, local_builds, conf_system
     ):
         tests.clean_database()
-        with tests.app.app_context():
-            module_build_service.utils.load_local_builds(db_session, ["testmodule"])
+        with app.app_context():
+            load_local_builds(["testmodule"])
 
-            resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="mbs")
+            resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
             result = resolver.get_buildrequired_modulemds(
                 "testmodule", "master", "platform:f28:1:00000000")
             assert 1 == len(result)
@@ -458,3 +470,49 @@ class TestMBSModule:
             assert "master" == mmd.get_stream_name()
             assert 20170816080816 == mmd.get_version()
             assert "321" == mmd.get_context()
+
+    @patch("module_build_service.resolver.MBSResolver.requests_session")
+    def test_get_buildrequired_modulemds_kojiresolver(self, mock_session):
+        """
+        Test that MBSResolver uses KojiResolver as input when KojiResolver is enabled for
+        the base module.
+        """
+        mock_session.get.return_value = Mock(ok=True)
+        mock_session.get.return_value.json.return_value = {
+            "items": [
+                {
+                    "name": "nodejs",
+                    "stream": "10",
+                    "version": 2,
+                    "context": "c1",
+                    "modulemd": mmd_to_str(
+                        tests.make_module("nodejs:10:2:c1"),
+                    ),
+                },
+            ],
+            "meta": {"next": None},
+        }
+
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="mbs")
+
+        platform = db_session.query(
+            module_build_service.common.models.ModuleBuild).filter_by(id=1).one()
+        platform_mmd = platform.mmd()
+        platform_xmd = platform_mmd.get_xmd()
+        platform_xmd["mbs"]["koji_tag_with_modules"] = "module-f29-build"
+        platform_mmd.set_xmd(platform_xmd)
+
+        with patch.object(
+                resolver, "get_buildrequired_koji_builds") as get_buildrequired_koji_builds:
+            get_buildrequired_koji_builds.return_value = [{
+                "build_id": 124, "name": "nodejs", "version": "10",
+                "release": "2.c1", "tag_name": "foo-test"}]
+            result = resolver.get_buildrequired_modulemds("nodejs", "10", platform_mmd)
+            get_buildrequired_koji_builds.assert_called_once()
+
+        assert 1 == len(result)
+        mmd = result[0]
+        assert "nodejs" == mmd.get_module_name()
+        assert "10" == mmd.get_stream_name()
+        assert 2 == mmd.get_version()
+        assert "c1" == mmd.get_context()
