@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MIT
+from __future__ import absolute_import
 from collections import namedtuple
 import errno
 
@@ -7,22 +8,22 @@ import dnf
 from mock import call, Mock, patch, PropertyMock
 import pytest
 
-from module_build_service.errors import UnprocessableEntity
-from module_build_service.models import ModuleBuild
+from module_build_service.common.config import conf
+from module_build_service.common.errors import UnprocessableEntity
+from module_build_service.common.models import ModuleBuild
+from module_build_service.common.utils import import_mmd, load_mmd, mmd_to_str
 from module_build_service.scheduler import default_modules
-from module_build_service.utils.general import load_mmd, mmd_to_str
-from tests import clean_database, conf, make_module_in_db, read_staged_data
+from module_build_service.scheduler.db_session import db_session
+from tests import clean_database, make_module_in_db, read_staged_data
 
 
 @patch("module_build_service.scheduler.default_modules.handle_collisions_with_base_module_rpms")
 @patch("module_build_service.scheduler.default_modules._get_default_modules")
-def test_add_default_modules(mock_get_dm, mock_hc, db_session):
+def test_add_default_modules(mock_get_dm, mock_hc):
     """
     Test that default modules present in the database are added, and the others are ignored.
     """
     clean_database()
-    make_module_in_db("python:3:12345:1", db_session=db_session)
-    make_module_in_db("nodejs:11:2345:2", db_session=db_session)
     mmd = load_mmd(read_staged_data("formatted_testmodule.yaml"))
     xmd_brs = mmd.get_xmd()["mbs"]["buildrequires"]
     assert set(xmd_brs.keys()) == {"platform"}
@@ -40,6 +41,12 @@ def test_add_default_modules(mock_get_dm, mock_hc, db_session):
     platform_xmd["mbs"]["use_default_modules"] = True
     platform_mmd.set_xmd(platform_xmd)
     platform.modulemd = mmd_to_str(platform_mmd)
+
+    dependencies = [
+        {"requires": {"platform": ["f28"]},
+         "buildrequires": {"platform": ["f28"]}}]
+    make_module_in_db("python:3:12345:1", base_module=platform, dependencies=dependencies)
+    make_module_in_db("nodejs:11:2345:2", base_module=platform, dependencies=dependencies)
     db_session.commit()
 
     mock_get_dm.return_value = {
@@ -47,7 +54,7 @@ def test_add_default_modules(mock_get_dm, mock_hc, db_session):
         "python": "3",
         "ruby": "2.6",
     }
-    defaults_added = default_modules.add_default_modules(db_session, mmd, ["x86_64"])
+    defaults_added = default_modules.add_default_modules(mmd)
     # Make sure that the default modules were added. ruby:2.6 will be ignored since it's not in
     # the database
     assert set(mmd.get_xmd()["mbs"]["buildrequires"].keys()) == {"nodejs", "platform", "python"}
@@ -60,19 +67,19 @@ def test_add_default_modules(mock_get_dm, mock_hc, db_session):
 
 
 @patch("module_build_service.scheduler.default_modules._get_default_modules")
-def test_add_default_modules_not_linked(mock_get_dm, db_session):
+def test_add_default_modules_not_linked(mock_get_dm):
     """
     Test that no default modules are added when they aren't linked from the base module.
     """
     clean_database()
     mmd = load_mmd(read_staged_data("formatted_testmodule.yaml"))
     assert set(mmd.get_xmd()["mbs"]["buildrequires"].keys()) == {"platform"}
-    default_modules.add_default_modules(db_session, mmd, ["x86_64"])
+    default_modules.add_default_modules(mmd)
     assert set(mmd.get_xmd()["mbs"]["buildrequires"].keys()) == {"platform"}
     mock_get_dm.assert_not_called()
 
 
-def test_add_default_modules_platform_not_available(db_session):
+def test_add_default_modules_platform_not_available():
     """
     Test that an exception is raised when the platform module that is buildrequired is missing.
 
@@ -83,17 +90,73 @@ def test_add_default_modules_platform_not_available(db_session):
 
     expected_error = "Failed to retrieve the module platform:f28:3:00000000 from the database"
     with pytest.raises(RuntimeError, match=expected_error):
-        default_modules.add_default_modules(db_session, mmd, ["x86_64"])
+        default_modules.add_default_modules(mmd)
 
 
 @patch("module_build_service.scheduler.default_modules._get_default_modules")
-def test_add_default_modules_request_failed(mock_get_dm, db_session):
+def test_add_default_modules_compatible_platforms(mock_get_dm):
+    """
+    Test that default modules built against compatible base module streams are added.
+    """
+    clean_database(add_platform_module=False)
+
+    # Create compatible base modules.
+    mmd = load_mmd(read_staged_data("platform"))
+    for stream in ["f27", "f28"]:
+        mmd = mmd.copy("platform", stream)
+
+        # Set the virtual stream to "fedora" to make these base modules compatible.
+        xmd = mmd.get_xmd()
+        xmd["mbs"]["virtual_streams"] = ["fedora"]
+        xmd["mbs"]["use_default_modules"] = True
+        mmd.set_xmd(xmd)
+        import_mmd(db_session, mmd)
+
+    mmd = load_mmd(read_staged_data("formatted_testmodule.yaml"))
+    xmd_brs = mmd.get_xmd()["mbs"]["buildrequires"]
+    assert set(xmd_brs.keys()) == {"platform"}
+
+    platform_f27 = ModuleBuild.get_build_from_nsvc(
+        db_session, "platform", "f27", "3", "00000000")
+    assert platform_f27
+
+    # Create python default module which requires platform:f27 and therefore cannot be used
+    # as default module for platform:f28.
+    dependencies = [
+        {"requires": {"platform": ["f27"]},
+         "buildrequires": {"platform": ["f27"]}}]
+    make_module_in_db("python:3:12345:1", base_module=platform_f27, dependencies=dependencies)
+
+    # Create nodejs default module which requries any platform stream and therefore can be used
+    # as default module for platform:f28.
+    dependencies[0]["requires"]["platform"] = []
+    make_module_in_db("nodejs:11:2345:2", base_module=platform_f27, dependencies=dependencies)
+    db_session.commit()
+
+    mock_get_dm.return_value = {
+        "nodejs": "11",
+        "python": "3",
+        "ruby": "2.6",
+    }
+    defaults_added = default_modules.add_default_modules(mmd)
+    # Make sure that the default modules were added. ruby:2.6 will be ignored since it's not in
+    # the database
+    assert set(mmd.get_xmd()["mbs"]["buildrequires"].keys()) == {"nodejs", "platform"}
+    mock_get_dm.assert_called_once_with(
+        "f28",
+        "https://pagure.io/releng/fedora-module-defaults.git",
+    )
+    assert defaults_added is True
+
+
+@patch("module_build_service.scheduler.default_modules._get_default_modules")
+def test_add_default_modules_request_failed(mock_get_dm):
     """
     Test that an exception is raised when the call to _get_default_modules failed.
     """
     clean_database()
-    make_module_in_db("python:3:12345:1", db_session=db_session)
-    make_module_in_db("nodejs:11:2345:2", db_session=db_session)
+    make_module_in_db("python:3:12345:1")
+    make_module_in_db("nodejs:11:2345:2")
     mmd = load_mmd(read_staged_data("formatted_testmodule.yaml"))
     xmd_brs = mmd.get_xmd()["mbs"]["buildrequires"]
     assert set(xmd_brs.keys()) == {"platform"}
@@ -117,7 +180,7 @@ def test_add_default_modules_request_failed(mock_get_dm, db_session):
     mock_get_dm.side_effect = ValueError(expected_error)
 
     with pytest.raises(ValueError, match=expected_error):
-        default_modules.add_default_modules(db_session, mmd, ["x86_64"])
+        default_modules.add_default_modules(mmd)
 
 
 @pytest.mark.parametrize("is_rawhide", (True, False))
@@ -182,7 +245,7 @@ def test_get_default_modules_invalid_branch(
     else:
         mock_get_rawhide.return_value = "something_else"
 
-    with pytest.raises(ValueError, match="Failed to retrieve the default modules"):
+    with pytest.raises(RuntimeError, match="Failed to retrieve the default modules"):
         default_modules._get_default_modules("f32", conf.default_modules_scm_url)
 
     mock_mmd_new.assert_not_called()
@@ -194,18 +257,18 @@ def test_get_default_modules_invalid_branch(
         mock_scm.return_value.checkout_ref.assert_called_once_with("f32")
 
 
-@patch("module_build_service.scheduler.default_modules.KojiModuleBuilder")
-def test_get_rawhide_version(mock_koji_builder):
+@patch("module_build_service.scheduler.default_modules.get_session")
+def test_get_rawhide_version(mock_get_session):
     """
     Test that _get_rawhide_version will return rawhide Fedora version.
     """
-    mock_koji_builder.get_session.return_value.getBuildTarget.return_value = {
+    mock_get_session.return_value.getBuildTarget.return_value = {
         "build_tag_name": "f32-build",
     }
     assert default_modules._get_rawhide_version() == "f32"
 
 
-@patch("module_build_service.scheduler.default_modules.KojiModuleBuilder.get_session")
+@patch("module_build_service.scheduler.default_modules.get_session")
 @patch("module_build_service.scheduler.default_modules._get_rpms_from_tags")
 def test_handle_collisions_with_base_module_rpms(mock_grft, mock_get_session):
     """
